<?php
/**
 * @package     HSChromeLogger!
 * @author      Hosting Skills a.s.b.l. - http://www.hosting-skills.lu
 * @copyright   Copyright (C) 2014-2017 Hosting Skills a.s.b.l.. All rights reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

// No direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

/**
 * HSChromeLogger! System Plugin Installer Script
 */
class plgSystemHSChromeLoggerInstallerScript
{
    /**
     * Version of the Plugin
     *
     * @var  string
     */
    protected $version;

    /**
     * Called before any type of action
     *
     * @param  string            $route    Which action is happening (install|uninstall|discover_install|update)
     * @param  JAdapterInstance  $adapter  The object responsible for running this script
     *
     * @return  boolean  True on success
     */
    public function preflight($route, JAdapterInstance $adapter) {
        $jversion = new JVersion();
        $this->version = $adapter->get('manifest')->version;
        $joomla_version = $adapter->get('manifest')->attributes()->version;

        if (version_compare($jversion->getShortVersion(), $joomla_version, 'lt')) {
            $adapter->getParent()->message = '';
            JFactory::getApplication()->enqueueMessage(sprintf(JText::_('PLG_HSCHROMELOGGER_JOOMLA_VERSION_ERROR'), $joomla_version), 'error');
            return false;
        }

        if ('update' == $route) {
            $db = $adapter->getParent()->getDbo();
            $query = $db->getQuery(true)
                ->select($db->quoteName('manifest_cache'))
                ->from($db->quoteName('#__extensions'))
                ->where($db->quoteName('name') . ' = ' . $db->quote($adapter->get('manifest')->name));
            $db->setQuery($query);

            try {
                $db->execute();
                $manifest = json_decode($db->loadResult(), true);
                $update_version = $manifest['version'];
            } catch (RuntimeException $e) {
                $update_version = $this->version;
            }

            if (version_compare($this->version, $update_version, 'le')) {
                $adapter->getParent()->message = '';
                JFactory::getApplication()->enqueueMessage(sprintf(JText::_('PLG_HSCHROMELOGGER_UPDATE_VERSION_ERROR'), $update_version, $this->version), 'error');
                return false;
            }
        }
    }

    /**
     * Called on installation
     *
     * @param  JAdapterInstance  $adapter  The object responsible for running this script
     *
     * @return  boolean  True on success
     */
    public function install(JAdapterInstance $adapter) {
        $adapter->getParent()->message = sprintf(JText::_('PLG_HSCHROMELOGGER_INSTALL'), $this->version).'<br /><br /><span style="color: red;">'.JText::_('PLG_HSCHROMELOGGER_CONFIGURE').'</span><br /><br /><img src="../plugins/system/hschromelogger/hschromelogger.png" alt="HSChromeLogger!" /><br /><br />';
    }

    /**
     * Called on update
     *
     * @param  JAdapterInstance  $adapter  The object responsible for running this script
     *
     * @return  boolean  True on success
     */
    public function update(JAdapterInstance $adapter) {
        $db = $adapter->getParent()->getDbo();
        $query = $db->getQuery(true)
            ->select($db->quoteName('enabled'))
            ->from($db->quoteName('#__extensions'))
            ->where($db->quoteName('name') . ' = ' . $db->quote($adapter->get('manifest')->name));
        $db->setQuery($query);

        try {
            $db->execute();
            $enabled = $db->loadResult();
        } catch (RuntimeException $e) {
            $enabled = false;
        }

        $adapter->getParent()->message = sprintf(JText::_('PLG_HSCHROMELOGGER_UPDATE'), $this->version).($enabled?'':'<br /><br /><span style="color: red;">'.JText::_('PLG_HSCHROMELOGGER_CONFIGURE')).'</span><br /><br /><img src="../plugins/system/hschromelogger/hschromelogger.png" alt="HSChromeLogger!" /><br /><br />';
    }
}